@@ -69,20 +69,21 @@ def init_log():
     # if user=='root':
     #     os.chmod(log_dir,0666)
     log_fmt_str = '%(asctime)-25s %(module)s:%(lineno)d  %(levelname)-8s %(message)s'
-    if PY2:
-        logging.basicConfig(level=logging.DEBUG,
-                            format=log_fmt_str,
-                            filemode='a+', filename=client_log_filename)
-    if PY3:
-        log_fmt_str = '%(asctime)s %(module)s:%(lineno)d  %(levelname)s %(message)s'
-        logging.basicConfig(level=logging.DEBUG,
-                            format=log_fmt_str, filename=client_log_filename)
+    # if PY2:
+    #     logging.basicConfig(level=logging.DEBUG,
+    #                         format=log_fmt_str,
+    #                         filemode='a+', filename=client_log_filename)
+    # if PY3:
+    #     log_fmt_str = '%(asctime)s %(module)s:%(lineno)d  %(levelname)s %(message)s'
+    #     logging.basicConfig(level=logging.DEBUG,
+    #                         format=log_fmt_str, filename=client_log_filename)
     logger = logging.getLogger('CLI')
     file_handler = RotatingFileHandler(filename=client_log_filename, maxBytes=100 * 1024 * 1024, backupCount=3)
     formatter = logging.Formatter(log_fmt_str)
     file_handler.setLevel(logging.DEBUG)
     file_handler.setFormatter(formatter)
     logger.addHandler(file_handler)
+    logger.setLevel(logging.DEBUG)
     if user == 'root' and PLATFORM != 'windows':
         try:
             if len(os.popen('command -v chattr').read()) > 1:
@@ -98,7 +99,7 @@ def init_log():
     return logger
 
 
-logger = logging.getLogger('CLI')
+logger = init_log()
 log = logger
 IS_INIT_GLOBAL_LOG = False
 HELP_DOC = '''
@@ -110,6 +111,14 @@ EXAMPLE_DOC = '''
 '''
 
 
+def ctrl_c(signum, frame):
+    sys.exit(1)
+
+
+signal.signal(signal.SIGINT, ctrl_c)
+signal.signal(signal.SIGTERM, ctrl_c)
+
+
 class ZbxCommon(object):
     def __init__(self, server_url=''):
         self.machine_id = ''
@@ -124,10 +133,29 @@ class ZbxCommon(object):
             self.get_param('')
 
     def init_log(self):
-        global logger, IS_INIT_GLOBAL_LOG
+        global logger, log, IS_INIT_GLOBAL_LOG
         if not IS_INIT_GLOBAL_LOG:
             IS_INIT_GLOBAL_LOG = True
-            logging = init_log()
+            self.log = init_log()
+            logger = self.log
+
+    @classmethod
+    def try_except_log(cls):
+        def decorator(func):
+            import functools
+            @functools.wraps(func)
+            def wrapper(*args, **kwargs):
+                try:
+                    return func(*args, **kwargs)
+                except Exception as err:
+                    name = ''
+                    if hasattr(func, '__name__'):
+                        name = getattr(func, '__name__')
+                    logger.error('func name:' + name + "\t" + str(err))
+
+            return wrapper
+
+        return decorator
 
     def urlencode(self, str):
         reprStr = repr(str).replace(r'\x', '%')
@@ -1000,6 +1028,16 @@ class ZbxCommon(object):
         import requests
         return requests
 
+    @property
+    def pymysql(self):
+        import pymysql
+        return pymysql
+
+    @property
+    def pyquery(self):
+        import pyquery
+        return pyquery
+
     @property
     def redis(self):
         import redis
@@ -1023,7 +1061,7 @@ class ZbxCommon(object):
         info = dsnparse.parse(dsn)
         config = {}
         if default_dict_config is not None:
-            config = {}
+            config = default_dict_config
         if hasattr(info, 'query'):
             new = getattr(info, 'query')
             config.update(new)
@@ -1035,16 +1073,16 @@ class ZbxCommon(object):
 
     def get_kafka_producer(self, dsn):
         '''
-        :param dsn: kafka://127.0.0.1:9002/topic?bootstrap_servers=127.0.0.1:9002,127.0.0.1:9003
+        :param dsn: kafka://127.0.0.1:9092/?bootstrap_servers=127.0.0.1:9002
         :return:
         '''
         import dsnparse
         config = self.parse_dsn_query_to_dict(dsn, self.kafka.KafkaProducer.DEFAULT_CONFIG)
-        info=dsnparse.parse(dsn)
+        info = dsnparse.parse(dsn)
         bootstrap_servers = config.get('bootstrap_servers')
         if bootstrap_servers is None:
-            bootstrap_servers = info.hostloc
-        consumer = self.kafka.KafkaProducer( **config)
+            config['bootstrap_servers'] == info.hostloc
+        consumer = self.kafka.KafkaProducer(**config)
         return consumer
 
     def get_kafka_consumer(self, dsn):
@@ -1054,11 +1092,13 @@ class ZbxCommon(object):
         '''
         import dsnparse
         config = self.parse_dsn_query_to_dict(dsn, self.kafka.KafkaConsumer.DEFAULT_CONFIG)
-        info=dsnparse.parse(dsn)
+        info = dsnparse.parse(dsn)
         bootstrap_servers = config.get('bootstrap_servers')
+        if info.dbname == '':
+            raise Exception('topic is null')
         if bootstrap_servers is None:
-            bootstrap_servers = info.hostloc
-        consumer = self.kafka.KafkaConsumer(info.dbname,bootstrap_servers, **config)
+            config['bootstrap_servers'] == info.hostloc
+        consumer = self.kafka.KafkaConsumer(info.dbname, **config)
         return consumer
 
     @property
@@ -1570,6 +1610,20 @@ except Exception as er:
 cli = ZbxCommon()
 
 
+@cli.try_except_log()
+def __check_module():
+    mds = cli.get_dependencies()
+    if len(mds) > 0:
+        for m in mds:
+            try:
+                __import__(m)
+            except Exception as err:
+                logger.warn('No module named: %s' % (m))
+
+
+__check_module()
+
+
 class CAS(object):
     def __init__(self, objname=''):
         self.objname = objname
@@ -1757,12 +1811,25 @@ r.set('a','b')
 print(r.get('a'))
 
 
-dsn="kafka://127.0.0.1:9002/topic?group_id=2&bootstrap_servers=127.0.0.1:9002,127.0.0.1:9003"
+def cc():
+    dsn="kafka://127.0.0.1:9092/test?group_id=2&bootstrap_servers=127.0.0.1:9092"
+    consumer=cli.get_kafka_consumer(dsn)
+    for m in consumer:
+        print(m)
+import threading
 
-cli.get_kafka_consumer(dsn)
+c=threading.Thread(target=cc)
+c.setDaemon(True)
+c.start()
+#
+dsn="kafka://127.0.0.1:9092/?bootstrap_servers=127.0.0.1:9092"
 
-dsn="kafka://127.0.0.1:9002/topic?bootstrap_servers=127.0.0.1:9002,127.0.0.1:9003"
+p=cli.get_kafka_producer(dsn)
+k=cli.kafka
 
-cli.get_kafka_producer(dsn)
+import time
+for i in range(1,1000):
+    p.send('test','xxx')
+    time.sleep(1)
 
 '''
